#ifndef _STRINPUT_H
#define _STRINPUT_H

#ifdef MOD_HTML2HDML
#include <stdio.h>
#include <errno.h>

#include "httpd.h"

#endif

struct clientinfo {
    int row;
    int column; 
};

struct convertopt {
    int a_href_html2hdml;
    int img;
    int img_src_gif2bmp;
    int img_alt;
#ifdef MOD_HTML2HDML
    request_rec *apache_r;
#endif
};

extern struct clientinfo gl_clientinfo;
extern struct convertopt gl_convertopt;

extern int set_inputstr(const char *input, int inputlen);

extern int func(const char *buffer, int buf_len,
		struct clientinfo *clientinfo,
		struct convertopt *convertopt);
#endif /* _STRINPUT_H */
